***
* Replication Archive for
* Gerber, Alan S., Eric M. Patashnik, David Doherty, and Conor M. Dowling. 2010. A National Survey 
* Reveals Skepticism about Research-Based Treatment Guidelines. Health Affairs 29: 1882-1884.
***

clear 
set mem 500m
cd "SET DIRECTORY"
//use "cces09_yale_output2_acceptmissing.dta" 
//keep cc09_30 v208 cc423 cc424 v213 v288 v246 v211 v261 v200 v217 v244 yal074-yal082 order74_82 v401
//save "replication.dta", replace
use "replication.dta", clear
cd tables
set more 1

***************************************
****** CODE UP DEMOGRAPHICS ***********
***************************************

gen weight=v200

gen race=v211
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White"
label var r_black "Black"
label var r_hispanic "Hispanic"
label var r_other "Other Race"

*vote report
recode cc09_30 (1 2=0) (3=1) (*=.),gen(voted08)

gen age=v288
gen age2=(age^2)/100

label var age "Age (in years)"
label var age2 "Age-squared/100"

recode v208 (1=0) (2=1), gen(female)
label var female "Female=1"

tab cc423, gen(pid_)
rename pid_1 pid_democrat
rename pid_2 pid_republican
gen pid_independent=pid_3+pid_4+pid_5
label var pid_democrat "Democrat"
label var pid_republican "Republican"
label var pid_independent "Independent"

recode cc424 (1=-3) (2=-2) (3=-1) (4 8=0) (5=1) (6=2) (7=3) (*=.), gen(pid)
recode cc423 (1=1) (2=2) (3 4 5=3) (*=.), gen(party3)
recode v261 (1=-2) (2=-1) (3 6=0) (4=1) (5=2) (*=.), gen(ideol)
label var pid "Party ID (-3=S. Dem; 3=S. Rep)"
label var ideol "Ideology (-2=V. Lib; 2=V. Cons)"

recode v217 (1=6) (2=5) (3=4) (4=3) (5=2) (6=1) (7=.), gen(religatt)
label var religatt "Religious Attendance (1 never;6 more than 1/week)"

recode v244 (1=4) (2=3) (3=2) (4=1) (*=.), gen(interest)
label var interest "Political Interest (1 hardly at all; 4 most of the time)"
recode interest (1 2=1) (3=2) (4=3) (4=1) (*=.), gen(interest3)
tab interest, gen(Dinterest)

gen educ=v213 
label var educ "Education (1 no HS; 6 postgrad)"

gen income=v246
label var income "Income (1=<$10k; 14=>150k; 15=RF)"

recode educ (1 2=1) (3 4=2) (5 6=3) (*=.), gen(educ3)
tab educ3, gen(Deduc)

recode income (1 2 3 4 5 6=1) (7 8 9=2) (10 11 12 13 14=3) (15=4), gen(income3)
tab income3, gen(Dincome)

gen incomemis=(income==15)
label var incomemis "Income Missing"

recode age (18/37=1) (38/51=2) (52/64=3) (65/98=4), gen(age4)
tab age4, gen(Dage)

label var age4 "Age (4-categories)"
label var income3 "Income (3-categories)"
label var educ3 "Education (3-categories)"
label var interest3 "Interest (3-categories)"

**************************************
***** DEFINE OUTCOME VARIABLES *******
**************************************

forvalues i=74/82{
tab yal0`i', gen(dich_`i'_)
gen dich_`i'_anyagree=dich_`i'_1+dich_`i'_2
rename dich_`i'_1 dich_`i'_strongagree
local vlabel : variable label yal0`i'
label var dich_`i'_strongagree "`vlabel' (Strongly Agree=1)"
label var dich_`i'_anyagree "`vlabel' (Any Agree=1)"
}
foreach i in anyagree strongagree{
egen treatg_pro_`i'=rmean(dich_74_`i' dich_75_`i' dich_76_`i' dich_77_`i')
egen treatg_con_`i'=rmean(dich_78_`i' dich_79_`i' dich_80_`i' dich_81_`i' dich_82_`i')
}

***DEFINE SAMPLE
reg dich_*_anyagree voted08 pid age educ income female r_black r_hispanic r_other
gen insample=e(sample)


*************************************
********* EXHIBIT 1 *****************
** Figure 3.3 in Unhealthy Politics *
*************************************
foreach i in 76 77 74 75 78 79 81 82 80{
if `i'==76{
qui ci mean dich_`i'_anyagree if insample==1 [aw=weight]
matrix means=r(mean)
matrix ci=(r(ub)-r(mean))
qui ci mean dich_`i'_strongagree if insample==1 [aw=weight]
matrix strmeans=r(mean)
matrix strci=(r(ub)-r(mean))
}
else{
qui ci mean dich_`i'_anyagree if insample==1 [aw=weight]
matrix means=means\r(mean)
matrix ci=ci\(r(ub)-r(mean))
qui ci mean dich_`i'_strongagree if insample==1 [aw=weight]
matrix strmeans=strmeans\r(mean)
matrix strci=strci\(r(ub)-r(mean))
}
}
matrix full=means,strmeans,ci,strci
svmat full, names(full)
outsheet full* using exhibit1.csv,comma replace

************************************
********* EXHIBIT 1A ***************
************************************
foreach i in 76 77 74 75 78 79 81 82 80{
qui ci mean dich_`i'_anyagree if insample==1 [aw=weight]
matrix item=r(mean)
qui ci mean dich_`i'_strongagree if insample==1 [aw=weight]
matrix stitem=r(mean)

forvalues p=0/1{
qui ci mean dich_`i'_anyagree if voted08==`p' & insample==1 [aw=weight]
matrix item=item,r(mean)
qui ci mean dich_`i'_strongagree if voted08==`p' & insample==1 [aw=weight]
matrix stitem=stitem,r(mean)
}
forvalues p=1/3{
qui ci mean dich_`i'_anyagree if party3==`p' & insample==1 [aw=weight]
matrix item=item,r(mean)
qui ci mean dich_`i'_strong if party3==`p' & insample==1 [aw=weight]
matrix stitem=stitem,r(mean)
}
forvalues p=1/4{
qui ci mean dich_`i'_anyagree if age4==`p' & insample==1 [aw=weight]
matrix item=item,r(mean)
qui ci mean dich_`i'_strongagree if age4==`p' & insample==1 [aw=weight]
matrix stitem=stitem,r(mean)
}
forvalues p=1/3{
qui ci mean dich_`i'_anyagree if educ3==`p' & insample==1 [aw=weight]
matrix item=item,r(mean)
qui ci mean dich_`i'_strongagree if educ3==`p' & insample==1 [aw=weight]
matrix stitem=stitem,r(mean)
}
matrix scratch=item\stitem
if `i'==76{
matrix full=scratch
}
else{
matrix full=full\scratch
}
}

drop full*
svmat full, names(full)
outsheet full* using exhibit1A.csv,comma replace

foreach i in 76 77 74 75 78 79 81 82 80{
qui reg dich_`i'_anyagree voted08 if insample==1 [aw=weight]
test voted08 
matrix item_any=r(p)
qui reg dich_`i'_strongagree voted08 if insample==1 [aw=weight]
test voted08 
matrix item_strong=r(p)

qui reg dich_`i'_anyagree pid_rep pid_dem if insample==1 [aw=weight]
test pid_rep pid_dem 
matrix item_any=item_any,r(p)
qui reg dich_`i'_strongagree pid_rep pid_dem if insample==1 [aw=weight]
test pid_rep pid_dem 
matrix item_strong=r(p),item_strong

qui reg dich_`i'_anyagree Dage1 Dage2 Dage3 if insample==1 [aw=weight]
test Dage1 Dage2 Dage3 
matrix item_any=item_any,r(p)
qui reg dich_`i'_strongagree Dage1 Dage2 Dage3 if insample==1 [aw=weight]
test Dage1 Dage2 Dage3 
matrix item_strong=r(p),item_strong

qui reg dich_`i'_anyagree Deduc2 Deduc3 if insample==1 [aw=weight]
test Deduc2 Deduc3 
matrix item_any=item_any,r(p)
qui reg dich_`i'_strongagree Deduc2 Deduc3 if insample==1 [aw=weight]
test Deduc2 Deduc3 
matrix item_strong=r(p),item_strong

matrix scratch=item_any\item_strong
if `i'==76{
matrix full=scratch
}
else{
matrix full=full\scratch
}
}
matrix list full


*** BLOCK ORDER EFFECTS
gen con_first=order74_82

foreach i in 76 77 74 75 78 79 81 82 80{
qui reg dich_`i'_anyagree con_first if insample==1 [aw=weight]
test con_first
matrix item_any=r(p)
lincom con_first
matrix item_any=item_any,r(estimate)

qui reg dich_`i'_strongagree con_first if insample==1 [aw=weight]
test con_first
matrix item_strong=r(p)
lincom con_first
matrix item_strong=item_strong,r(estimate)

matrix scratch=item_any\item_strong
if `i'==76{
matrix full=scratch
}
else{
matrix full=full\scratch
}
}
matrix list full


*** DATE OF SURVEY
gen day= day(dofc(v401))
gen month= month(dofc(v401))
gen premammogram=(day<16 & month==11)
gen mammogram=(day>=16 & month==11)

forvalues i=74/82{
reg yal0`i' mammogram if insample==1 [aw=weight], r
}
